@@ -212,6 +212,14 @@ class MetaArray(type):
         if "_c_type" not in data:
             data["_c_type"] = name
 
+        # determine has_refs
+        if '_itemtype' in data.keys():
+            if (hasattr(data['_itemtype'], '_has_refs')
+                 and data['_itemtype']._has_refs):
+                data['_has_refs'] = True
+            else:
+                data['_has_refs'] = False
+
         return type.__new__(cls, name, bases, data)
 
     def __getitem__(cls, shape):
