@@ -245,6 +245,11 @@ class ContextCpu(XContext):
             xtr_compile_args.append("-fopenmp")
             xtr_link_args.append("-fopenmp")
 
+        if os.name == 'nt': #windows
+            # TODO: to be handled properly
+            xtr_compile_args = []
+            xtr_link_args = []
+
         ffi_interface.set_source(
             tempfname,
             specialized_source,
@@ -284,8 +289,12 @@ class ContextCpu(XContext):
         finally:
             # Clean temp files
             files_to_remove = [so_fname, tempfname + ".c", tempfname + ".o"]
+
             for ff in files_to_remove:
                 if os.path.exists(ff):
+                    if os.name == 'nt' and ff.endswith('.pyd'): 
+                        # pyd files are protected on windows
+                        continue
                     os.remove(ff)
 
     def nparray_to_context_array(self, arr):
